@@ -19,7 +19,7 @@ Readonly::Scalar our $YEAR_FROM => 1855;
 Readonly::Scalar our $YEAR_TO => 2054;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -336,10 +336,25 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Business::DK::CPR>,
-L<No::PersonNr>,
-L<Person::ID::CZ::RC>,
-L<Se::PersonNr>.
+=over
+
+=item L<Business::DK::CPR>
+
+Danish CPR (SSN) number generator/validator
+
+=item L<No::PersonNr>
+
+Check Norwegian Social security numbers
+
+=item L<Person::ID::CZ::RC>
+
+Perl class for Czech RC identification.
+
+=item L<Se::PersonNr>
+
+Module for validating and generating a Swedish personnummer.
+
+=back
 
 =head1 REPOSITORY
 
@@ -353,10 +368,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © Michal Špaček 2013-2015
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
